#[non_exhaustive]pub struct CodecCapabilitySet {
pub text: bool,
pub layout: bool,
pub confidence: bool,
pub timestamps: bool,
}Expand description
Orthogonal document codec capabilities delivered or advertised by a codec.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.text: boolCodec can emit text.
layout: boolCodec can emit layout geometry.
confidence: boolCodec can emit confidence buckets.
timestamps: boolCodec can emit timestamps.
Implementations
Sourceimpl CodecCapabilitySet
impl CodecCapabilitySet
Sourcepub const TEXT_ONLY: CodecCapabilitySet
pub const TEXT_ONLY: CodecCapabilitySet
Text-only capability set.
Sourcepub const fn new(
text: bool,
layout: bool,
confidence: bool,
timestamps: bool,
) -> CodecCapabilitySet
pub const fn new( text: bool, layout: bool, confidence: bool, timestamps: bool, ) -> CodecCapabilitySet
Builds a codec capability bitset.
Sourcepub fn contains(self, requested: CodecCapabilitySet) -> bool
pub fn contains(self, requested: CodecCapabilitySet) -> bool
Returns true when this set contains every requested capability bit.