pub struct LocaleChain(/* private fields */);Expand description
Ordered locale fallback chain.
Implementations
Sourceimpl LocaleChain
impl LocaleChain
Builds a locale chain and appends global fallback when absent.
Sourcepub fn from_cli(raw: &str) -> Result<LocaleChain, LocaleError>
pub fn from_cli(raw: &str) -> Result<LocaleChain, LocaleError>
Parses a comma-separated CLI locale chain.
Sourcepub fn merge_policy_and_cli(
policy: Option<&[LocaleTag]>,
cli: Option<&[LocaleTag]>,
) -> LocaleChain
pub fn merge_policy_and_cli( policy: Option<&[LocaleTag]>, cli: Option<&[LocaleTag]>, ) -> LocaleChain
Merges policy and CLI locale preferences.
Sourcepub fn merge_cli_policy_rulepack_default(
cli: Option<&[LocaleTag]>,
policy: Option<&[LocaleTag]>,
rulepack_defaults: Option<&[LocaleTag]>,
) -> LocaleChain
pub fn merge_cli_policy_rulepack_default( cli: Option<&[LocaleTag]>, policy: Option<&[LocaleTag]>, rulepack_defaults: Option<&[LocaleTag]>, ) -> LocaleChain
Merges CLI, policy, rulepack, and default locale preferences.
Sourcepub fn intersects(&self, recognizer_locales: &[LocaleTag]) -> bool
pub fn intersects(&self, recognizer_locales: &[LocaleTag]) -> bool
Returns true when a recognizer can run under this locale chain.
Sourcepub fn to_strings(&self) -> Vec<String>
pub fn to_strings(&self) -> Vec<String>
Returns the locale chain as canonical strings.